@@ -8,7 +8,17 @@ from flask.helpers import safe_join, send_file
 from werkzeug.exceptions import NotFound
 
 
-def _fallback_to(folders):
+def _normalize(locations):
+    rv = []
+    for location in locations:
+        if isinstance(location, (list, tuple)):
+            prefix, folder = location
+        else:
+            prefix, folder = '', location
+        rv.append((prefix, folder))
+    return rv
+
+def _fallback_to(locations):
     def send_static(filename):
         """Sends a file from the static folder if a given file exist.
         Otherwise, tries additional folders as a fallback.
@@ -16,16 +26,18 @@ def _fallback_to(folders):
         try:
             return current_app.send_static_file(filename)
         except NotFound:
-            for folder in folders:
+            for prefix, folder in locations:
+                if prefix:
+                    prefix = '{}{}'.format(prefix, os.sep)
+                    if filename.startswith(prefix):
+                        filename = filename[len(prefix):]
                 filepath = safe_join(folder, filename)
                 if os.path.isfile(filepath):
-                    current_app.logger.debug("Found, sending '%s' from '%s'",
-                                             filename, folder)
                     return send_file(filepath)
             raise NotFound()
     return send_static
 
-def mount_folders(app, folders):
+def mount_folders(app, locations):
     """Sets up the additional static locations that the application will traverse.
     This function does nothing in debug mode.
     """
@@ -33,4 +45,5 @@ def mount_folders(app, folders):
         if app.view_functions['static'] != app.send_static_file:
             warn("The endpoint function was already redefined in your "
                  "application. Old changes will not show up.")
-        app.view_functions['static'] = _fallback_to(set(folders))
+        locations = _normalize(locations)
+        app.view_functions['static'] = _fallback_to(locations)
